@@ -22,6 +22,11 @@ from .exec import (
     do_select_one,
     do_query,
     do_query_one,
+    load,
+    do_load,
+    insert_from_csv,
+    insert_from_df,
+    insert_from_json,
     get_connection,
     close,
 )
