@@ -1,6 +1,6 @@
-from typing import Sequence
 from functools import lru_cache
 from .log_support import logger
+from typing import Collection, Tuple
 from .constant import CACHE_SIZE, UNKNOW
 
 _ENGINE = None
@@ -37,7 +37,7 @@ class Engine:
 
     @classmethod
     @lru_cache(maxsize=CACHE_SIZE)
-    def create_insert_sql_intf(cls, table: str, cols: Sequence[str]):
+    def create_insert_sql_intf(cls, table: str, cols: Tuple[str]):
         return _ENGINE.create_insert_sql(table, cols)
 
     @staticmethod
@@ -57,7 +57,7 @@ class Engine:
         return _ENGINE.before_execute(function, sql, *args)
 
     @staticmethod
-    def create_insert_sql(table: str, cols: Sequence[str]):
+    def create_insert_sql(table: str, cols: Collection[str]):
         columns, placeholders = zip(*[('{}'.format(col), '?') for col in cols])
         return 'INSERT INTO {}({}) VALUES({})'.format(table, ', '.join(columns), ','.join(placeholders))
 
