@@ -145,30 +145,30 @@ def execute(sql: str, *args, **kwargs):
     return do_execute(sql, *args)
 
 
-def insert(table: str, **kwargs):
+def insert(table_name: str, **kwargs):
     """
     Insert data into table, return effect rowcount.
 
-    :param table: table name
+    :param table_name: table name
     :param kwargs: {name='张三', age=20}
     return: Effect rowcount
     """
-    insert_log('insert', table, **kwargs)
-    sql, args = sql_support.insert_sql_args(table.strip(), **kwargs)
+    insert_log('insert', table_name, **kwargs)
+    sql, args = sql_support.insert_sql_args(table_name.strip(), **kwargs)
     return execute(sql, *args)
 
 
-def save(select_key: str, table: str, **kwargs) -> int:
+def save(select_key: str, table_name: str, **kwargs) -> int:
     """
     Insert data into table, return primary key.
 
     :param select_key: sql for select primary key
-    :param table: table
+    :param table_name: table name
     :param kwargs: {name='张三', age=20}
     :return: Primary key
     """
-    save_log('save', select_key, table, **kwargs)
-    sql, args = sql_support.insert_sql_args(table.strip(), **kwargs)
+    save_log('save', select_key, table_name, **kwargs)
+    sql, args = sql_support.insert_sql_args(table_name.strip(), **kwargs)
     return save_sql(select_key, sql, *args)
 
 
@@ -323,15 +323,15 @@ def do_query_one(sql: str, *args):
     return result
 
 
-def batch_insert(table: str, *args):
+def batch_insert(table_name: str, *args):
     """
     Batch insert
-    :param table: table name
+    :param table_name: table name
     :param args: All number must have same key. [{'name': '张三', 'age': 20}, {'name': '李四', 'age': 28}]
     :return: Effect row count
     """
-    logger.debug("Exec func 'sqlexec.%s' \n\t Table: '%s', args: %s" % ('batch_insert', table, args))
-    sql, args = sql_support.batch_insert_sql_args(table, *args)
+    logger.debug("Exec func 'sqlexec.%s' \n\t Table: '%s', args: %s" % ('batch_insert', table_name, args))
+    sql, args = sql_support.batch_insert_sql_args(table_name, *args)
     return batch_execute(sql, *args)
 
 
@@ -388,14 +388,14 @@ def do_load(sql: str, *args) -> Loader:
     return Loader(result, description)
 
 
-def insert_from_csv(file_name: str, table: str, delimiter=',', header=True, columns: Collection[str] = None, encoding='utf-8'):
+def insert_from_csv(file_name: str, table_name: str, delimiter=',', header=True, columns: Collection[str] = None, encoding='utf-8'):
     """
     sqlexec.insert_from_csv('test.csv', 'person')
     """
     import csv
     sql = None
     if columns and len(columns) > 0:
-        sql = sql_support.insert_sql(table.strip(), columns)
+        sql = sql_support.insert_sql(table_name.strip(), columns)
     elif not header:
         raise ValueError("Expected one of 'header' and 'columns'.")
 
@@ -411,22 +411,22 @@ def insert_from_csv(file_name: str, table: str, delimiter=',', header=True, colu
             return 0
 
         if sql is None:
-            sql = sql_support.insert_sql(table.strip(), lines[0])
+            sql = sql_support.insert_sql(table_name.strip(), lines[0])
         lines = lines[1:]
 
     return batch_execute(sql, lines)
 
 
-def insert_from_df(df, table: str, columns: Collection[str] = None):
+def insert_from_df(df, table_name: str, columns: Collection[str] = None):
     """
     sqlexec.insert_from_df(df, 'person')
     """
     columns = columns if columns and len(columns) > 0 else df.columns.tolist()
-    sql = sql_support.insert_sql(table.strip(), columns)
+    sql = sql_support.insert_sql(table_name.strip(), columns)
     return batch_execute(sql, df.values.tolist())
 
 
-def insert_from_json(file_name: str, table: str, encoding='utf-8'):
+def insert_from_json(file_name: str, table_name: str, encoding='utf-8'):
     """
     sqlexec.insert_from_json('test.json', 'person')
 
@@ -442,11 +442,11 @@ def insert_from_json(file_name: str, table: str, encoding='utf-8'):
         data = json.load(f)
 
     if isinstance(data, dict):
-        return insert(table, **data)
+        return insert(table_name, **data)
     elif isinstance(data, Iterable):
-        return batch_insert(table, data)
+        return batch_insert(table_name, data)
     else:
-        logger.info("Exec func 'sqlexec.%s' \n\t Table: '%s' insert 0 rows." % ('insert_from_json', table ))
+        logger.info("Exec func 'sqlexec.%s' \n\t Table: '%s' insert 0 rows." % ('insert_from_json', table_name ))
         return 0
 
 
