@@ -1,11 +1,14 @@
+#！/usr/bin/env python3
+# -*- coding:utf-8 -*-
+
 from . import exec
 from .loader import Loader
 
 
 class Param:
 
-    def __init__(self, sqlExec, *args, **kwargs):
-        self.sqlExec = sqlExec
+    def __init__(self, sql_exec, *args, **kwargs):
+        self.sql_exec = sql_exec
         self.args = args
         self.kwargs = kwargs
 
@@ -13,61 +16,61 @@ class Param:
         """
         sqlexec.sql('INSERT INTO person(name, age) VALUES(?, ?)').param('张三', 18).execute()
         """
-        return self.sqlExec.execute(*self.args, **self.kwargs)
+        return self.sql_exec.execute(*self.args, **self.kwargs)
 
     def save(self, select_key: str):
         """
         sqlexec.sql('INSERT INTO person(name, age) VALUES(?, ?)').param('张三', 18).save('SELECT LAST_INSERT_ID()')
         """
-        return self.sqlExec.save(select_key, *self.args, **self.kwargs)
+        return self.sql_exec.save(select_key, *self.args, **self.kwargs)
 
     def get(self):
         """
         sqlexec.sql('SELECT count(1) FROM person WHERE name=? and age=? limit 1').param('张三', 18).get()
         """
-        return self.sqlExec.get(*self.args, **self.kwargs)
+        return self.sql_exec.get(*self.args, **self.kwargs)
 
     def select(self):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).select()
         """
-        return self.sqlExec.select(*self.args, **self.kwargs)
+        return self.sql_exec.select(*self.args, **self.kwargs)
 
     def select_one(self):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=? limit 1').param('张三', 18).select_one()
         """
-        return self.sqlExec.select_one(*self.args, **self.kwargs)
+        return self.sql_exec.select_one(*self.args, **self.kwargs)
 
     def query(self):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).query()
         """
-        return self.sqlExec.query(*self.args, **self.kwargs)
+        return self.sql_exec.query(*self.args, **self.kwargs)
 
     def query_one(self):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=? limit 1').param('张三', 18).query_one()
         """
-        return self.sqlExec.query_one(*self.args, **self.kwargs)
+        return self.sql_exec.query_one(*self.args, **self.kwargs)
 
     def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).csv('test.csv')
         """
-        self.sqlExec.load(*self.args, **self.kwargs).csv(file_name, delimiter, header, encoding)
+        self.sql_exec.load(*self.args, **self.kwargs).csv(file_name, delimiter, header, encoding)
 
     def df(self):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).df()
         """
-        return self.sqlExec.load(*self.args, **self.kwargs).df()
+        return self.sql_exec.load(*self.args, **self.kwargs).df()
 
     def json(self, file_name: str, encoding='utf-8'):
         """
         sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).json('test.json')
         """
-        self.sqlExec.load(*self.args, **self.kwargs).json(file_name, encoding)
+        self.sql_exec.load(*self.args, **self.kwargs).json(file_name, encoding)
 
 
 class SqlExec:
